@@ -15,7 +15,7 @@ extern "C" {
 
 extern void	ct_mainloop_add_socket(ct_socket_t *);
 extern void	ct_mainloop(void);
-extern void	ct_mainloop_leave();
+extern void	ct_mainloop_leave(void);
 
 #ifdef __cplusplus
 }
